@@ -1,3 +1,10 @@
+/*
+  sudokuselectnumberwidget.h
+  Project: masudoku
+  Platform: Fremantle (maemo5)
+  Author: Petri Kultanen pete@petnetti.net
+  Last Edit: 15.2.2010
+*/
 #ifndef SUDOKUSELECTNUMBERWIDGET_H
 #define SUDOKUSELECTNUMBERWIDGET_H
 
@@ -5,10 +12,11 @@
 class CSudokuTable;
 class QPaintEvent;
 class QMouseEvent;
-enum NumberTypes{
+enum NumberTypes
+{
     ENormalNumbers =0,
     EMarkupNumbers=1
-               };
+};
 
 class SudokuSelectNumberWidget : public QWidget
 {
