@@ -1,3 +1,10 @@
+/*
+  sudokutablewidget.h
+  Project: masudoku
+  Platform: Fremantle (maemo5)
+  Author: Petri Kultanen pete@petnetti.net
+  Last Edit: 15.2.2010
+*/
 #ifndef SUDOKUTABLEWIDGET_H
 #define SUDOKUTABLEWIDGET_H
 
@@ -16,12 +23,12 @@ public:
     void mousePressEvent(QMouseEvent * aEvent);
     void setSelectedCoordinates(int aX,int aY);
 signals:
-        void slotSelected(int aX,int aY);
+    void slotSelected(int aX,int aY);
 
 private:
-CSudokuTable *iTable;
-int iSelectedX; /// used for drawing mark to cell that is being edited.
-int iSelectedY;
+    CSudokuTable *iTable;
+    int iSelectedX; /// used for drawing mark to cell that is being edited.
+    int iSelectedY;
 };
 
 #endif // SUDOKUTABLEWIDGET_H
